@@ -50,15 +50,17 @@
 #'
 #' tidy(rec, number = 3)
 step_bin2factor <-
-  function(recipe,
-           ...,
-           role = NA,
-           trained = FALSE,
-           levels = c("yes", "no"),
-           ref_first = TRUE,
-           columns = NULL,
-           skip = FALSE,
-           id = rand_id("bin2factor")) {
+  function(
+    recipe,
+    ...,
+    role = NA,
+    trained = FALSE,
+    levels = c("yes", "no"),
+    ref_first = TRUE,
+    columns = NULL,
+    skip = FALSE,
+    id = rand_id("bin2factor")
+  ) {
     if (length(levels) != 2 || !is.character(levels)) {
       msg <- c(x = "{.arg levels} should be a 2-element character string.")
 
@@ -154,7 +156,6 @@ print.step_bin2factor <-
     invisible(x)
   }
 
-
 #' @rdname tidy.recipe
 #' @export
 tidy.step_bin2factor <- function(x, ...) {
