@@ -1,4 +1,4 @@
-#' B-Spline Basis Functions
+#' B-spline basis functions
 #'
 #' `step_bs()` creates a *specification* of a recipe step that will create new
 #' columns that are basis expansions of variables using B-splines.
@@ -20,15 +20,20 @@
 #' @details `step_bs` can create new features from a single variable
 #'  that enable fitting routines to model this variable in a
 #'  nonlinear manner. The extent of the possible nonlinearity is
-#'  determined by the `df`, `degree`, or `knot` arguments of
+#'  determined by the `df`, `degree`, or `knots` arguments of
 #'  [splines::bs()]. The original variables are removed
 #'  from the data and new columns are added. The naming convention
 #'  for the new variables is `varname_bs_1` and so on.
 #'
-#'  # Tidying
+#' # Tidying
 #'
-#'  When you [`tidy()`][tidy.recipe()] this step, a tibble with column
-#'  `terms` (the columns that will be affected) is returned.
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble is returned with
+#' columns `terms` and `id`:
+#'
+#' \describe{
+#'   \item{terms}{character, the selectors or variables selected}
+#'   \item{id}{character, id of this step}
+#' }
 #'
 #' ```{r, echo = FALSE, results="asis"}
 #' step <- "step_bs"
@@ -56,17 +61,19 @@
 #' expanded <- bake(with_splines, biomass_te)
 #' expanded
 step_bs <-
-  function(recipe,
-           ...,
-           role = "predictor",
-           trained = FALSE,
-           deg_free = NULL,
-           degree = 3,
-           objects = NULL,
-           options = list(),
-           keep_original_cols = FALSE,
-           skip = FALSE,
-           id = rand_id("bs")) {
+  function(
+    recipe,
+    ...,
+    role = "predictor",
+    trained = FALSE,
+    deg_free = NULL,
+    degree = 3,
+    objects = NULL,
+    options = list(),
+    keep_original_cols = FALSE,
+    skip = FALSE,
+    id = rand_id("bs")
+  ) {
     add_step(
       recipe,
       step_bs_new(
@@ -85,8 +92,18 @@ step_bs <-
   }
 
 step_bs_new <-
-  function(terms, role, trained, deg_free, degree, objects, options,
-           keep_original_cols, skip, id) {
+  function(
+    terms,
+    role,
+    trained,
+    deg_free,
+    degree,
+    objects,
+    options,
+    keep_original_cols,
+    skip,
+    id
+  ) {
     step(
       subclass = "bs",
       terms = terms,
@@ -111,12 +128,20 @@ bs_statistics <- function(x, args) {
 
   # This behaves differently from splines::bs() and splines::ns() if num_knots < 0L
   # the original implementations issue a warning.
-  if (!is.null(args$df) && is.null(args$knots) && args$df - degree - intercept >= 1L) {
+  if (
+    !is.null(args$df) &&
+      is.null(args$knots) &&
+      args$df - degree - intercept >= 1L
+  ) {
     num_knots <- args$df - degree - intercept
     ok <- !is.na(x) & x >= boundary[1L] & x <= boundary[2L]
     knots <- unname(quantile(x[ok], seq_len(num_knots) / (num_knots + 1L)))
   } else {
-    knots <- numeric()
+    if (is.null(args$knots)) {
+      knots <- numeric()
+    } else {
+      knots <- args$knots
+    }
   }
 
   # Only construct the data necessary for splines_predict
@@ -178,14 +203,14 @@ bake.step_bs <- function(object, new_data, ...) {
     colnames(new_values) <- new_names
 
     new_values <- check_name(new_values, new_data, object, new_names)
-    new_data <- vctrs::vec_cbind(new_data, new_values)
+    new_data <- vctrs::vec_cbind(new_data, new_values, .name_repair = "minimal")
   }
 
   new_data <- remove_original_cols(new_data, object, col_names)
   new_data
 }
 
-
+#' @export
 print.step_bs <-
   function(x, width = max(20, options()$width - 28), ...) {
     title <- "B-splines on "
