@@ -28,12 +28,14 @@
 #' bake(biomass_rec, biomass[, c("carbon", "HHV")])
 #' }
 check_cols <-
-  function(recipe,
-           ...,
-           role = NA,
-           trained = FALSE,
-           skip = FALSE,
-           id = rand_id("cols")) {
+  function(
+    recipe,
+    ...,
+    role = NA,
+    trained = FALSE,
+    skip = FALSE,
+    id = rand_id("cols")
+  ) {
     add_check(
       recipe,
       check_cols_new(
@@ -84,11 +86,13 @@ bake.check_cols <- function(object, new_data, ...) {
     # This is functionally not reachable after we added ptype checking in
     # https://github.com/tidymodels/recipes/pull/1330
     # but it feels too harsh to deprecate this check function.
-    cli::cli_abort(c(
-      x = "{cli::qty(length(missing))}The following column{?s} {?is/are} \\
+    cli::cli_abort(
+      c(
+        x = "{cli::qty(length(missing))}The following column{?s} {?is/are} \\
       missing from {.arg new_data}:",
-      "*" = "{.and {.var {missing}}}."
-    ))
+        "*" = "{.and {.var {missing}}}."
+      )
+    )
   }
   new_data
 }
