@@ -46,6 +46,8 @@
 #'   \item{id}{character, id of this step}
 #' }
 #'
+#' @template sparse-creation
+#'
 #' @template case-weights-not-supported
 #'
 #' @examples
@@ -76,20 +78,22 @@
 #' tidy(dummy_multi_choice_rec2, number = 1)
 #'
 #' @export
-step_dummy_multi_choice <- function(recipe,
-                                    ...,
-                                    role = "predictor",
-                                    trained = FALSE,
-                                    threshold = 0,
-                                    levels = NULL,
-                                    input = NULL,
-                                    other = "other",
-                                    naming = dummy_names,
-                                    prefix = NULL,
-                                    keep_original_cols = FALSE,
-                                    skip = FALSE,
-                                    id = rand_id("dummy_multi_choice")) {
-
+step_dummy_multi_choice <- function(
+  recipe,
+  ...,
+  role = "predictor",
+  trained = FALSE,
+  threshold = 0,
+  levels = NULL,
+  input = NULL,
+  other = "other",
+  naming = dummy_names,
+  prefix = NULL,
+  sparse = "auto",
+  keep_original_cols = FALSE,
+  skip = FALSE,
+  id = rand_id("dummy_multi_choice")
+) {
   add_step(
     recipe,
     step_dummy_multi_choice_new(
@@ -102,6 +106,7 @@ step_dummy_multi_choice <- function(recipe,
       other = other,
       naming = naming,
       prefix = prefix,
+      sparse = sparse,
       keep_original_cols = keep_original_cols,
       skip = skip,
       id = id
@@ -110,8 +115,21 @@ step_dummy_multi_choice <- function(recipe,
 }
 
 step_dummy_multi_choice_new <-
-  function(terms, role, trained, threshold, levels, input, other, naming,
-           prefix, keep_original_cols, skip, id) {
+  function(
+    terms,
+    role,
+    trained,
+    threshold,
+    levels,
+    input,
+    other,
+    naming,
+    prefix,
+    sparse,
+    keep_original_cols,
+    skip,
+    id
+  ) {
     step(
       subclass = "dummy_multi_choice",
       terms = terms,
@@ -123,6 +141,7 @@ step_dummy_multi_choice_new <-
       other = other,
       naming = naming,
       prefix = prefix,
+      sparse = sparse,
       keep_original_cols = keep_original_cols,
       skip = skip,
       id = id
@@ -140,9 +159,14 @@ prep.step_dummy_multi_choice <- function(x, training, info = NULL, ...) {
   }
   check_string(x$other, arg = "other", allow_null = TRUE)
   check_function(x$naming, arg = "naming", allow_empty = FALSE)
+  check_sparse_arg(x$sparse)
 
   levels <- purrr::map(training[, col_names], levels)
-  levels <- vctrs::list_unchop(levels, ptype = character(), name_spec = rlang::zap())
+  levels <- vctrs::list_unchop(
+    levels,
+    ptype = character(),
+    name_spec = rlang::zap()
+  )
   levels <- levels[!is.na(levels)]
   levels <- keep_levels(levels, x$threshold, other = x$other)
 
@@ -156,6 +180,7 @@ prep.step_dummy_multi_choice <- function(x, training, info = NULL, ...) {
     other = x$other,
     naming = x$naming,
     prefix = x$prefix,
+    sparse = x$sparse,
     keep_original_cols = get_keep_original_cols(x),
     skip = x$skip,
     id = x$id
@@ -167,7 +192,23 @@ bake.step_dummy_multi_choice <- function(object, new_data, ...) {
   col_names <- object$input
   check_new_data(col_names, object, new_data)
 
-  indicators <- multi_dummy(new_data[, col_names], object$levels)
+  if (length(col_names) == 0) {
+    return(new_data)
+  }
+
+  indicators <- multi_dummy(
+    new_data[, col_names],
+    object$levels,
+    sparse_is_yes(object$sparse)
+  )
+
+  if (sparse_is_yes(object$sparse)) {
+    indicators <- purrr::map(indicators, sparsevctrs::as_sparse_integer)
+  } else {
+    indicators <- purrr::map(indicators, vec_cast, integer())
+  }
+
+  indicators <- tibble::new_tibble(indicators)
 
   prefix <- object$prefix
   if (is.null(prefix)) {
@@ -180,13 +221,13 @@ bake.step_dummy_multi_choice <- function(object, new_data, ...) {
 
   indicators <- check_name(indicators, new_data, object, names(indicators))
 
-  new_data <- vec_cbind(new_data, indicators)
+  new_data <- vec_cbind(new_data, indicators, .name_repair = "minimal")
   new_data <- remove_original_cols(new_data, object, col_names)
 
   new_data
 }
 
-multi_dummy <- function(x, y) {
+multi_dummy <- function(x, y, sparse = FALSE) {
   row_id <- rep(seq_len(nrow(x)), times = ncol(x))
   values <- vctrs::list_unchop(
     purrr::map(x, as.character),
@@ -201,7 +242,6 @@ multi_dummy <- function(x, y) {
   row_id <- row_id[!is.na(values)]
   values <- values[!is.na(values)]
 
-
   original_levels <- c(y$keep, y$other)
 
   values <- factor(values, levels = original_levels)
@@ -214,19 +254,18 @@ multi_dummy <- function(x, y) {
 
   colnames(res) <- levels(values)
 
-  res <- as.matrix(res)
-  if (ncol(res) > 0) {
-    res <- apply(res, 2, as.integer, simplify = FALSE)
+  if (sparse) {
+    res <- sparsevctrs::coerce_to_sparse_tibble(res)
+  } else {
+    res <- as.matrix(res)
+    res <- as_tibble(res)
   }
 
-  # to preserve old behavior drop other if empty
-  res <- as_tibble(res)
-
   if (sum(res[y$other]) == 0) {
     res <- dplyr::select(res, -y$other)
   }
 
-  return(res)
+  res
 }
 
 #' @export
@@ -273,3 +312,27 @@ tunable.step_dummy_multi_choice <- function(x, ...) {
     component_id = x$id
   )
 }
+
+#' @export
+.recipes_estimate_sparsity.step_dummy_multi_choice <- function(x, data, ...) {
+  get_levels <- function(x) {
+    if (is.factor(x)) {
+      return(levels(x))
+    } else {
+      return(unique(x))
+    }
+  }
+
+  n_levels <- purrr::map(data, get_levels)
+  n_levels <- unlist(n_levels)
+  n_levels <- unique(n_levels)
+  n_levels <- na.omit(n_levels)
+  n_levels <- length(n_levels)
+
+  lapply(n_levels, function(n_lvl) {
+    c(
+      n_cols = n_lvl,
+      sparsity = 1 - 1 / n_lvl
+    )
+  })
+}
