@@ -1,11 +1,13 @@
-#' Create Missing Data Column Indicators
+#' Create missing data column indicators
 #'
 #' `step_indicate_na()` creates a *specification* of a recipe step that will
 #' create and append additional binary columns to the data set to indicate which
 #' observations are missing.
 #'
+#' @inheritParams step_classdist
 #' @inheritParams step_pca
 #' @inheritParams step_center
+#' @inheritParams step_dummy
 #' @param prefix A character string that will be the prefix to the
 #'  resulting new variables. Defaults to "na_ind".
 #' @template step-return
@@ -13,9 +15,15 @@
 #'
 #' # Tidying
 #'
-#' When you [`tidy()`][tidy.recipe()] this step, a tibble with columns
-#' `terms` (the selectors or variables selected) and `model` (the
-#' median value) is returned.
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble is returned with
+#' columns `terms` and `id`:
+#'
+#' \describe{
+#'   \item{terms}{character, the selectors or variables selected}
+#'   \item{id}{character, id of this step}
+#' }
+#'
+#' @template sparse-creation
 #'
 #' @template case-weights-not-supported
 #'
@@ -40,17 +48,20 @@
 #'
 #' imp_models <- prep(impute_rec, training = credit_tr)
 #'
-#' imputed_te <- bake(imp_models, new_data = credit_te, everything())
+#' imputed_te <- bake(imp_models, new_data = credit_te)
 step_indicate_na <-
-  function(recipe,
-           ...,
-           role = "predictor",
-           trained = FALSE,
-           columns = NULL,
-           prefix = "na_ind",
-           keep_original_cols = TRUE,
-           skip = FALSE,
-           id = rand_id("indicate_na")) {
+  function(
+    recipe,
+    ...,
+    role = "predictor",
+    trained = FALSE,
+    columns = NULL,
+    prefix = "na_ind",
+    sparse = "auto",
+    keep_original_cols = TRUE,
+    skip = FALSE,
+    id = rand_id("indicate_na")
+  ) {
     terms <- enquos(...)
 
     add_step(
@@ -61,6 +72,7 @@ step_indicate_na <-
         trained = trained,
         columns = columns,
         prefix = prefix,
+        sparse = sparse,
         keep_original_cols = keep_original_cols,
         skip = skip,
         id = id
@@ -69,8 +81,17 @@ step_indicate_na <-
   }
 
 step_indicate_na_new <-
-  function(terms, role, trained, columns, prefix, keep_original_cols, skip,
-           id) {
+  function(
+    terms,
+    role,
+    trained,
+    columns,
+    prefix,
+    sparse,
+    keep_original_cols,
+    skip,
+    id
+  ) {
     step(
       subclass = "indicate_na",
       terms = terms,
@@ -78,6 +99,7 @@ step_indicate_na_new <-
       trained = trained,
       columns = columns,
       prefix = prefix,
+      sparse = sparse,
       keep_original_cols = keep_original_cols,
       skip = skip,
       id = id
@@ -87,6 +109,7 @@ step_indicate_na_new <-
 #' @export
 prep.step_indicate_na <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
+  check_sparse_arg(x$sparse)
 
   step_indicate_na_new(
     terms = x$terms,
@@ -94,6 +117,7 @@ prep.step_indicate_na <- function(x, training, info = NULL, ...) {
     trained = TRUE,
     columns = col_names,
     prefix = x$prefix,
+    sparse = x$sparse,
     keep_original_cols = get_keep_original_cols(x),
     skip = x$skip,
     id = x$id
@@ -108,7 +132,16 @@ bake.step_indicate_na <- function(object, new_data, ...) {
   cols <- list()
 
   for (col_name in col_names) {
-    cols[[col_name]] <- ifelse(is.na(new_data[[col_name]]), 1L, 0L)
+    if (sparse_is_yes(object$sparse)) {
+      positions <- which(is.na(new_data[[col_name]]))
+      cols[[col_name]] <- sparsevctrs::sparse_integer(
+        values = rep(1, length(positions)),
+        positions = positions,
+        length = length(new_data[[col_name]])
+      )
+    } else {
+      cols[[col_name]] <- ifelse(is.na(new_data[[col_name]]), 1L, 0L)
+    }
   }
 
   cols <- tibble::new_tibble(cols, nrow = nrow(new_data))
@@ -116,11 +149,12 @@ bake.step_indicate_na <- function(object, new_data, ...) {
 
   cols <- check_name(cols, new_data, object, names(cols))
 
-  new_data <- vec_cbind(new_data, cols)
+  new_data <- vec_cbind(new_data, cols, .name_repair = "minimal")
   new_data <- remove_original_cols(new_data, object, col_names)
   new_data
 }
 
+#' @export
 print.step_indicate_na <-
   function(x, width = max(20, options()$width - 30), ...) {
     title <- "Creating missing data variable indicators for "
@@ -139,3 +173,11 @@ tidy.step_indicate_na <- function(x, ...) {
   res$id <- x$id
   res
 }
+
+#' @export
+.recipes_estimate_sparsity.step_indicate_na <- function(x, data, ...) {
+  lapply(
+    seq_len(ncol(data)),
+    function(x) c(n_cols = 1, sparsity = 1)
+  )
+}
