@@ -19,10 +19,16 @@
 #' @export
 #'
 #' @details
+#'
 #' # Tidying
 #'
-#' When you [`tidy()`][tidy.recipe()] this step, a tibble with column
-#' `terms` (the columns that will be affected) is returned.
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble is returned with
+#' columns `terms` and `id`:
+#'
+#' \describe{
+#'   \item{terms}{character, the selectors or variables selected}
+#'   \item{id}{character, id of this step}
+#' }
 #'
 #' @template case-weights-not-supported
 #'
@@ -44,19 +50,23 @@
 #'
 #' with_intercept <- bake(rec_obj, biomass_te)
 #' with_intercept
-step_intercept <- function(recipe, ..., role = "predictor",
-                           trained = FALSE, name = "intercept",
-                           value = 1L,
-                           skip = FALSE, id = rand_id("intercept")) {
+step_intercept <- function(
+  recipe,
+  ...,
+  role = "predictor",
+  trained = FALSE,
+  name = "intercept",
+  value = 1L,
+  skip = FALSE,
+  id = rand_id("intercept")
+) {
   if (length(list(...)) > 0) {
-    rlang::warn("Selectors are not used for this step.")
-  }
-  if (!is.numeric(value)) {
-    rlang::abort("Intercept value must be numeric.")
-  }
-  if (!is.character(name) | length(name) != 1) {
-    rlang::abort("Intercept/constant column name must be a character value.")
+    cli::cli_warn("Selectors are not used for this step.")
   }
+
+  check_number_decimal(value)
+  check_string(name)
+
   add_step(
     recipe,
     step_intercept_new(
@@ -93,10 +103,11 @@ prep.step_intercept <- function(x, training, info = NULL, ...) {
 bake.step_intercept <- function(object, new_data, ...) {
   intercept <- tibble(!!object$name := rep(object$value, nrow(new_data)))
   intercept <- check_name(intercept, new_data, object, names(intercept))
-  new_data <- vec_cbind(intercept, new_data)
+  new_data <- vec_cbind(intercept, new_data, .name_repair = "minimal")
   new_data
 }
 
+#' @export
 print.step_intercept <-
   function(x, width = max(20, options()$width - 30), ...) {
     title <- "Adding intercept named: "
