@@ -6,6 +6,8 @@
 #' @inheritParams step_pca
 #' @inheritParams step_center
 #' @param ... Name-value pairs of expressions. See [dplyr::mutate()].
+#' @param .pkgs Character vector, package names of functions used in
+#'   expressions `...`. Should be specified if using non-base functions.
 #' @param inputs Quosure(s) of `...`.
 #' @template step-return
 #' @template mutate-leakage
@@ -18,11 +20,16 @@
 #'  If a preceding step removes a column that is selected by name in
 #'  `step_mutate()`, the recipe will error when being estimated with [prep()].
 #'
-#'  # Tidying
+#' # Tidying
 #'
-#'  When you [`tidy()`][tidy.recipe()] this step, a tibble with column
-#'  `values`, which contains the `mutate()` expressions as character
-#'  strings (and are not reparsable), is returned.
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble is returned with
+#' columns `terms`, `value` , and `id`:
+#'
+#' \describe{
+#'   \item{terms}{character, the selectors or variables selected}
+#'   \item{value}{character, expression passed to `mutate()`}
+#'   \item{id}{character, id of this step}
+#' }
 #'
 #' @template case-weights-not-supported
 #'
@@ -79,19 +86,27 @@
 #'
 #' # The difference:
 #' tidy(qq_rec, number = 1)
-step_mutate <- function(recipe, ...,
-                        role = "predictor",
-                        trained = FALSE,
-                        inputs = NULL,
-                        skip = FALSE,
-                        id = rand_id("mutate")) {
+step_mutate <- function(
+  recipe,
+  ...,
+  .pkgs = character(),
+  role = "predictor",
+  trained = FALSE,
+  inputs = NULL,
+  skip = FALSE,
+  id = rand_id("mutate")
+) {
+  check_character(.pkgs)
+  recipes_pkg_check(required_pkgs.step_mutate(list(.pkgs = .pkgs)))
+
   inputs <- enquos(...)
 
   add_step(
     recipe,
     step_mutate_new(
-      trained = trained,
+      .pkgs = .pkgs,
       role = role,
+      trained = trained,
       inputs = inputs,
       skip = skip,
       id = id
@@ -100,9 +115,10 @@ step_mutate <- function(recipe, ...,
 }
 
 step_mutate_new <-
-  function(role, trained, inputs, skip, id) {
+  function(.pkgs, role, trained, inputs, skip, id) {
     step(
       subclass = "mutate",
+      .pkgs = .pkgs,
       role = role,
       trained = trained,
       inputs = inputs,
@@ -115,6 +131,7 @@ step_mutate_new <-
 prep.step_mutate <- function(x, training, info = NULL, ...) {
   step_mutate_new(
     trained = TRUE,
+    .pkgs = x$.pkgs,
     role = x$role,
     inputs = x$inputs,
     skip = x$skip,
@@ -127,7 +144,7 @@ bake.step_mutate <- function(object, new_data, ...) {
   dplyr::mutate(new_data, !!!object$inputs)
 }
 
-
+#' @export
 print.step_mutate <-
   function(x, width = max(20, options()$width - 35), ...) {
     title <- "Variable mutation for "
@@ -149,3 +166,9 @@ tidy.step_mutate <- function(x, ...) {
     id = rep(x$id, length(x$inputs))
   )
 }
+
+#' @rdname required_pkgs.recipe
+#' @export
+required_pkgs.step_mutate <- function(x, ...) {
+  x$.pkgs
+}
