@@ -15,9 +15,15 @@
 #'
 #' # Tidying
 #'
-#' When you [`tidy()`][tidy.recipe()] this step, a tibble with column
-#' `terms` which contains the `select` expressions as character strings
-#' (and are not reparsable) is returned.
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble is returned with
+#' columns `terms` and `id`:
+#'
+#' \describe{
+#'   \item{terms}{character, the selectors or variables selected}
+#'   \item{id}{character, id of this step}
+#' }
+#'
+#' @template sparse-preserve
 #'
 #' @template case-weights-not-supported
 #'
@@ -57,12 +63,14 @@
 #'
 #' # Note that `sepal_vars` is inlined in the second approach
 #' qq_rec
-step_select <- function(recipe,
-                        ...,
-                        role = NA,
-                        trained = FALSE,
-                        skip = FALSE,
-                        id = rand_id("select")) {
+step_select <- function(
+  recipe,
+  ...,
+  role = NA,
+  trained = FALSE,
+  skip = FALSE,
+  id = rand_id("select")
+) {
   add_step(
     recipe,
     step_select_new(
@@ -105,7 +113,7 @@ bake.step_select <- function(object, new_data, ...) {
   dplyr::select(new_data, dplyr::all_of(object$terms))
 }
 
-
+#' @export
 print.step_select <-
   function(x, width = max(20, options()$width - 35), ...) {
     title <- "Variables selected "
@@ -126,3 +134,8 @@ tidy.step_select <- function(x, ...) {
   res$id <- x$id
   res
 }
+
+#' @export
+.recipes_preserve_sparsity.step_select <- function(x, ...) {
+  TRUE
+}
