@@ -15,10 +15,17 @@
 #'   to embed the value of the object in the expression (to
 #'   be portable between sessions). See the examples.
 #'
-#'  # Tidying
+#' # Tidying
 #'
-#'  When you [`tidy()`][tidy.recipe()] this step, a tibble with column
-#'  `terms` which contains the filtering indices is returned.
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble is returned with
+#' columns `terms` and `id`:
+#'
+#' \describe{
+#'   \item{terms}{character, containing the filtering indices}
+#'   \item{id}{character, id of this step}
+#' }
+#'
+#' @template sparse-preserve
 #'
 #' @template case-weights-not-supported
 #'
@@ -46,8 +53,8 @@
 #' dplyr_test <-
 #'   iris %>%
 #'   as_tibble() %>%
-#'   slice(76:150) %>%
-#'   slice(1:3)
+#'   slice(76:150)
+#'
 #' rec_test <- bake(prepped, iris %>% slice(76:150))
 #' all.equal(dplyr_test, rec_test)
 #'
@@ -58,17 +65,20 @@
 #'
 #' qq_rec <-
 #'   recipe(~., data = iris) %>%
-#'   # Embed `keep_rows` in the call using !!
-#'   step_slice(!!keep_rows) %>%
+#'   # Embed `keep_rows` in the call using !!!
+#'   step_slice(!!!keep_rows) %>%
 #'   prep(training = iris)
 #'
 #' tidy(qq_rec, number = 1)
-step_slice <- function(recipe, ...,
-                       role = NA,
-                       trained = FALSE,
-                       inputs = NULL,
-                       skip = TRUE,
-                       id = rand_id("slice")) {
+step_slice <- function(
+  recipe,
+  ...,
+  role = NA,
+  trained = FALSE,
+  inputs = NULL,
+  skip = TRUE,
+  id = rand_id("slice")
+) {
   inputs <- enquos(...)
 
   add_step(
@@ -114,7 +124,7 @@ bake.step_slice <- function(object, new_data, ...) {
   dplyr::slice(new_data, !!!object$inputs)
 }
 
-
+#' @export
 print.step_slice <-
   function(x, width = max(20, options()$width - 35), ...) {
     title <- "Row filtering via position "
@@ -133,3 +143,8 @@ tidy.step_slice <- function(x, ...) {
     id = rep(x$id, length(x$inputs))
   )
 }
+
+#' @export
+.recipes_preserve_sparsity.step_slice <- function(x, ...) {
+  TRUE
+}
