@@ -79,19 +79,20 @@
 #' @template case-weights-not-supported
 #' @seealso [splines2::mSpline()]
 step_spline_nonnegative <-
-  function(recipe,
-           ...,
-           role = "predictor",
-           trained = FALSE,
-           deg_free = 10,
-           degree = 3,
-           complete_set = FALSE,
-           options = NULL,
-           keep_original_cols = FALSE,
-           results = NULL,
-           skip = FALSE,
-           id = rand_id("spline_nonnegative")) {
-
+  function(
+    recipe,
+    ...,
+    role = "predictor",
+    trained = FALSE,
+    deg_free = 10,
+    degree = 3,
+    complete_set = FALSE,
+    options = NULL,
+    keep_original_cols = FALSE,
+    results = NULL,
+    skip = FALSE,
+    id = rand_id("spline_nonnegative")
+  ) {
     recipes_pkg_check(required_pkgs.step_spline_nonnegative())
 
     add_step(
@@ -113,8 +114,20 @@ step_spline_nonnegative <-
   }
 
 step_spline_nonnegative_new <-
-  function(terms, trained, role, deg_free, degree, complete_set, options,
-           keep_original_cols, results, na_rm, skip, id) {
+  function(
+    terms,
+    trained,
+    role,
+    deg_free,
+    degree,
+    complete_set,
+    options,
+    keep_original_cols,
+    results,
+    na_rm,
+    skip,
+    id
+  ) {
     step(
       subclass = "spline_nonnegative",
       terms = terms,
@@ -196,7 +209,7 @@ bake.step_spline_nonnegative <- function(object, new_data, ...) {
   new_cols <- purrr::list_cbind(unname(new_cols))
   new_cols <- check_name(new_cols, new_data, object, names(new_cols))
 
-  new_data <- vec_cbind(new_data, new_cols)
+  new_data <- vec_cbind(new_data, new_cols, .name_repair = "minimal")
   new_data <- remove_original_cols(new_data, object, col_names)
 
   new_data
