@@ -1,4 +1,4 @@
-#' Zero Variance Filter
+#' Zero variance filter
 #'
 #' `step_zv()` creates a *specification* of a recipe step that will remove
 #' variables that contain only a single value.
@@ -18,8 +18,15 @@
 #'
 #' # Tidying
 #'
-#' When you [`tidy()`][tidy.recipe()] this step, a tibble with column
-#' `terms` (the columns that will be removed) is returned.
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble is returned with
+#' columns `terms` and `id`:
+#'
+#' \describe{
+#'   \item{terms}{character, names of the columns that will be removed}
+#'   \item{id}{character, id of this step}
+#' }
+#'
+#' @template sparse-preserve
 #'
 #' @template case-weights-not-supported
 #'
@@ -50,14 +57,16 @@
 #' tidy(zv_filter, number = 1)
 #' tidy(filter_obj, number = 1)
 step_zv <-
-  function(recipe,
-           ...,
-           role = NA,
-           trained = FALSE,
-           group = NULL,
-           removals = NULL,
-           skip = FALSE,
-           id = rand_id("zv")) {
+  function(
+    recipe,
+    ...,
+    role = NA,
+    trained = FALSE,
+    group = NULL,
+    removals = NULL,
+    skip = FALSE,
+    id = rand_id("zv")
+  ) {
     add_step(
       recipe,
       step_zv_new(
@@ -88,7 +97,12 @@ step_zv_new <-
 
 one_unique <- function(x) {
   x <- x[!is.na(x)]
-  length(unique(x)) < 2
+  if (sparsevctrs::is_sparse_vector(x)) {
+    res <- length(unique(sparsevctrs::sparse_values(x))) == 0
+  } else {
+    res <- length(unique(x)) < 2
+  }
+  res
 }
 
 group_one_unique <- function(x, f) {
@@ -129,6 +143,7 @@ bake.step_zv <- function(object, new_data, ...) {
   new_data
 }
 
+#' @export
 print.step_zv <-
   function(x, width = max(20, options()$width - 38), ...) {
     if (x$trained) {
@@ -140,7 +155,11 @@ print.step_zv <-
     invisible(x)
   }
 
-
 #' @rdname tidy.recipe
 #' @export
 tidy.step_zv <- tidy_filter
+
+#' @export
+.recipes_preserve_sparsity.step_zv <- function(x, ...) {
+  TRUE
+}
