@@ -63,7 +63,7 @@ test_that("occasional missing values", {
 test_that("tunable", {
   rec <-
     recipe(~., data = iris) %>%
-    step_corr(all_predictors())
+      step_corr(all_predictors())
   rec_param <- tunable.step_corr(rec$steps[[1]])
   expect_equal(rec_param$name, c("threshold"))
   expect_true(all(rec_param$source == "recipe"))
@@ -77,9 +77,11 @@ test_that("tunable", {
 
 test_that("case weights", {
   dat_caseweights <- dat %>%
-    mutate(V3_dup = V3 + rep(c(0, 1), c(50, 50)),
-           wts = rep(c(1, 2), c(50, 50)),
-           wts = frequency_weights(wts))
+    mutate(
+      V3_dup = V3 + rep(c(0, 1), c(50, 50)),
+      wts = rep(c(1, 2), c(50, 50)),
+      wts = frequency_weights(wts)
+    )
 
   # low filter
   filtering <- recipe(~., data = dat_caseweights) %>%
@@ -105,9 +107,11 @@ test_that("case weights", {
 
   # ----------------------------------------------------------------------------
   dat_caseweights <- dat %>%
-    mutate(V3_dup = V3 + rep(c(0, 1), c(50, 50)),
-           wts = rep(c(1, 2), c(50, 50)),
-           wts = importance_weights(wts))
+    mutate(
+      V3_dup = V3 + rep(c(0, 1), c(50, 50)),
+      wts = rep(c(1, 2), c(50, 50)),
+      wts = importance_weights(wts)
+    )
 
   # low filter
   filtering <- recipe(~., data = dat_caseweights) %>%
@@ -199,8 +203,7 @@ test_that("printing", {
 test_that("tunable is setup to work with extract_parameter_set_dials", {
   skip_if_not_installed("dials")
   rec <- recipe(~., data = mtcars) %>%
-    step_corr(all_predictors(),
-              threshold = hardhat::tune())
+    step_corr(all_predictors(), threshold = hardhat::tune())
 
   params <- extract_parameter_set_dials(rec)
 
@@ -228,4 +231,3 @@ test_that("bad args", {
     error = TRUE
   )
 })
-
