@@ -6,7 +6,7 @@ data(covers, package = "modeldata")
 covers$rows <- 1:nrow(covers)
 covers$ch_rows <- paste(1:nrow(covers))
 
-rec <- recipe(~ description + rows + ch_rows, covers)
+rec <- recipe(~description + rows + ch_rows, covers)
 
 counts <- gregexpr(pattern = "(rock|stony)", text = covers$description)
 counts <- vapply(counts, function(x) length(x[x > 0]), integer(1))
@@ -16,9 +16,11 @@ test_that("default options", {
   rec1 <- rec %>%
     step_count(description, pattern = "(rock|stony)") %>%
     step_count(description, pattern = "", result = "every thing") %>%
-    step_count(description,
+    step_count(
+      description,
       pattern = "(rock|stony)",
-      result = "pct", normalize = TRUE
+      result = "pct",
+      normalize = TRUE
     )
   rec1 <- prep(rec1, training = covers)
   res1 <- bake(rec1, new_data = covers)
@@ -31,10 +33,10 @@ test_that("default options", {
   expect_false(is.integer(res1$pct))
 })
 
-
 test_that("nondefault options", {
   rec2 <- rec %>%
-    step_count(description,
+    step_count(
+      description,
       pattern = "(rock|stony)",
       result = "rocks",
       options = list(fixed = TRUE)
@@ -44,15 +46,13 @@ test_that("nondefault options", {
   expect_equal(res2$rocks, rep(0, nrow(covers)))
 })
 
-
 test_that("bad selector(s)", {
-  expect_snapshot(error = TRUE,
+  expect_snapshot(
+    error = TRUE,
     rec %>% step_count(description, rows, pattern = "(rock|stony)")
   )
   rec2 <- rec %>% step_count(rows, pattern = "(rock|stony)")
-  expect_snapshot(error = TRUE,
-    prep(rec2, training = covers)
-  )
+  expect_snapshot(error = TRUE, prep(rec2, training = covers))
 })
 
 test_that("check_name() is used", {
@@ -75,6 +75,63 @@ test_that("checks for grepl arguments", {
   )
 })
 
+test_that("sparse = 'yes' works", {
+  rec <- recipe(~description, covers)
+
+  suppressWarnings({
+    dense <- rec %>%
+      step_count(
+        description,
+        pattern = "stony",
+        sparse = "no",
+        keep_original_cols = FALSE
+      ) %>%
+      prep() %>%
+      bake(NULL)
+    sparse <- rec %>%
+      step_count(
+        description,
+        pattern = "stony",
+        sparse = "yes",
+        keep_original_cols = FALSE
+      ) %>%
+      prep() %>%
+      bake(NULL)
+  })
+
+  expect_identical(dense, sparse)
+
+  expect_false(any(vapply(dense, sparsevctrs::is_sparse_vector, logical(1))))
+  expect_true(all(vapply(sparse, sparsevctrs::is_sparse_vector, logical(1))))
+})
+
+test_that("sparse argument is backwards compatible", {
+  rec <- recipe(~description, covers) %>%
+    step_count(description, pattern = "stony") %>%
+    prep()
+
+  exp <- bake(rec, covers)
+
+  # Simulate old recipe
+  rec$steps[[1]]$sparse <- NULL
+
+  expect_identical(
+    bake(rec, covers),
+    exp
+  )
+})
+
+test_that(".recipes_toggle_sparse_args works", {
+  rec <- recipe(~description, covers) %>%
+    step_count(description, pattern = "stony", sparse = "auto")
+
+  exp <- rec %>% prep() %>% bake(NULL) %>% sparsevctrs::sparsity()
+
+  expect_true(
+    .recipes_estimate_sparsity(rec) > exp
+  )
+})
+
 # Infrastructure ---------------------------------------------------------------
 
 test_that("bake method errors when needed non-standard role columns are missing", {
@@ -83,14 +140,17 @@ test_that("bake method errors when needed non-standard role columns are missing"
 
   rec <-
     mt_tibble %>%
-    recipe(mpg ~ ., data = .) %>%
-    step_count(make_model, pattern = "Toyota", result = "is_toyota") %>%
-    update_role(make_model, new_role = "potato") %>%
-    update_role_requirements(role = "potato", bake = FALSE)
+      recipe(mpg ~ ., data = .) %>%
+      step_count(make_model, pattern = "Toyota", result = "is_toyota") %>%
+      update_role(make_model, new_role = "potato") %>%
+      update_role_requirements(role = "potato", bake = FALSE)
 
   rec_trained <- prep(rec, training = mt_tibble)
 
-  expect_snapshot(error = TRUE, bake(rec_trained, new_data = mt_tibble[,c(-1)]))
+  expect_snapshot(
+    error = TRUE,
+    bake(rec_trained, new_data = mt_tibble[, c(-1)])
+  )
 })
 
 test_that("empty printing", {
@@ -133,9 +193,13 @@ test_that("empty selection tidy method works", {
 test_that("keep_original_cols works", {
   new_names <- c("rocks")
 
-  rec <- recipe(~ description, covers) %>%
-    step_count(description, pattern = "(rock|stony)", result = "rocks",
-               keep_original_cols = FALSE)
+  rec <- recipe(~description, covers) %>%
+    step_count(
+      description,
+      pattern = "(rock|stony)",
+      result = "rocks",
+      keep_original_cols = FALSE
+    )
 
   rec <- prep(rec)
   res <- bake(rec, new_data = NULL)
@@ -145,9 +209,13 @@ test_that("keep_original_cols works", {
     new_names
   )
 
-  rec <- recipe(~ description, covers) %>%
-    step_count(description, pattern = "(rock|stony)", result = "rocks",
-               keep_original_cols = TRUE)
+  rec <- recipe(~description, covers) %>%
+    step_count(
+      description,
+      pattern = "(rock|stony)",
+      result = "rocks",
+      keep_original_cols = TRUE
+    )
 
   rec <- prep(rec)
   res <- bake(rec, new_data = NULL)
@@ -159,9 +227,13 @@ test_that("keep_original_cols works", {
 })
 
 test_that("keep_original_cols - can prep recipes with it missing", {
-  rec <- recipe(~ description, covers) %>%
-    step_count(description, pattern = "(rock|stony)", result = "rocks",
-               keep_original_cols = FALSE)
+  rec <- recipe(~description, covers) %>%
+    step_count(
+      description,
+      pattern = "(rock|stony)",
+      result = "rocks",
+      keep_original_cols = FALSE
+    )
 
   rec$steps[[1]]$keep_original_cols <- NULL
 
