@@ -6,19 +6,24 @@ rand_data <- data.frame(x = round(runif(10), 2), y = round(runif(10), 2))
 rand_data$x[1] <- NA
 
 dists <-
-  apply(as.matrix(rand_data),
+  apply(
+    as.matrix(rand_data),
     1,
     function(x, y, z) {
       sqrt((x[1] - y)^2 + (x[2] - z)^2)
     },
-    y = 0.5, z = 0.25
+    y = 0.5,
+    z = 0.25
   )
 
-
 test_that("basic functionality", {
-  rec <- recipe(~ x + y, data = rand_data) %>%
-    step_geodist(x, y,
-      ref_lat = 0.5, ref_lon = 0.25, is_lat_lon = FALSE,
+  rec <- recipe(~x + y, data = rand_data) %>%
+    step_geodist(
+      x,
+      y,
+      ref_lat = 0.5,
+      ref_lon = 0.25,
+      is_lat_lon = FALSE,
       log = FALSE
     )
   rec_trained <- prep(rec, training = rand_data)
@@ -29,9 +34,13 @@ test_that("basic functionality", {
   expect_equal(tr_int[["geo_dist"]], dists)
   expect_equal(te_int[["geo_dist"]], dists)
 
-  rec_log <- recipe(~ x + y, data = rand_data) %>%
-    step_geodist(x, y,
-      ref_lat = 0.5, ref_lon = 0.25, is_lat_lon = FALSE,
+  rec_log <- recipe(~x + y, data = rand_data) %>%
+    step_geodist(
+      x,
+      y,
+      ref_lat = 0.5,
+      ref_lon = 0.25,
+      is_lat_lon = FALSE,
       log = TRUE
     )
   rec_log_trained <- prep(rec_log, training = rand_data)
@@ -47,20 +56,25 @@ test_that("lat lon", {
   postal <- tibble(latitude = 0, longitude = 0)
   near_station <- recipe(~., data = postal) %>%
     step_geodist(
-      lat = latitude, lon = longitude, log = FALSE,
-      ref_lat = 0, ref_lon = 0,
+      lat = latitude,
+      lon = longitude,
+      log = FALSE,
+      ref_lat = 0,
+      ref_lon = 0,
       is_lat_lon = TRUE
     ) %>%
     prep() %>%
     bake(new_data = NULL)
   expect_equal(near_station[["geo_dist"]], 0)
 
-
   postal <- tibble(latitude = 38.8981014, longitude = -77.0104265)
   near_station <- recipe(~., data = postal) %>%
     step_geodist(
-      lat = latitude, lon = longitude, log = FALSE,
-      ref_lat = 38.8986312, ref_lon = -77.0062457,
+      lat = latitude,
+      lon = longitude,
+      log = FALSE,
+      ref_lat = 38.8986312,
+      ref_lon = -77.0062457,
       is_lat_lon = TRUE
     ) %>%
     prep() %>%
@@ -68,85 +82,116 @@ test_that("lat lon", {
 
   expect_equal(near_station[["geo_dist"]], 367, tolerance = 1)
 
-
-  expect_snapshot(error = TRUE,
+  expect_snapshot(
+    error = TRUE,
     near_station <- recipe(~., data = postal) %>%
       step_geodist(
-        lat = latitude, lon = longitude, log = FALSE,
-        ref_lat = 100, ref_lon = 100,
+        lat = latitude,
+        lon = longitude,
+        log = FALSE,
+        ref_lat = 100,
+        ref_lon = 100,
         is_lat_lon = TRUE
       ) %>%
       prep()
   )
 
-  expect_snapshot(error = TRUE,
+  expect_snapshot(
+    error = TRUE,
     near_station <- recipe(~., data = postal) %>%
       step_geodist(
-        lat = latitude, lon = longitude, log = FALSE,
-        ref_lat = 0, ref_lon = 190,
+        lat = latitude,
+        lon = longitude,
+        log = FALSE,
+        ref_lat = 0,
+        ref_lon = 190,
         is_lat_lon = TRUE
       ) %>%
       prep()
   )
 
-  expect_snapshot(error = TRUE,
+  expect_snapshot(
+    error = TRUE,
     near_station <- recipe(~., data = postal) %>%
       step_geodist(
-        lat = latitude, lon = longitude, log = FALSE,
-        ref_lat = -100, ref_lon = 0,
+        lat = latitude,
+        lon = longitude,
+        log = FALSE,
+        ref_lat = -100,
+        ref_lon = 0,
         is_lat_lon = TRUE
       ) %>%
       prep()
   )
 
-  expect_snapshot(error = TRUE,
+  expect_snapshot(
+    error = TRUE,
     near_station <- recipe(~., data = postal) %>%
       step_geodist(
-        lat = latitude, lon = longitude, log = FALSE,
-        ref_lat = 0, ref_lon = -190,
+        lat = latitude,
+        lon = longitude,
+        log = FALSE,
+        ref_lat = 0,
+        ref_lon = -190,
         is_lat_lon = TRUE
       ) %>%
       prep()
   )
 
   postal <- tibble(latitude = 100, longitude = 0)
-  expect_snapshot(error = TRUE,
+  expect_snapshot(
+    error = TRUE,
     near_station <- recipe(~., data = postal) %>%
       step_geodist(
-        lat = latitude, lon = longitude, log = FALSE,
-        ref_lat = 38.8986312, ref_lon = -77.0062457,
+        lat = latitude,
+        lon = longitude,
+        log = FALSE,
+        ref_lat = 38.8986312,
+        ref_lon = -77.0062457,
         is_lat_lon = TRUE
       ) %>%
       prep()
   )
 
   postal <- tibble(latitude = 0, longitude = 190)
-  expect_snapshot(error = TRUE,
+  expect_snapshot(
+    error = TRUE,
     near_station <- recipe(~., data = postal) %>%
       step_geodist(
-        lat = latitude, lon = longitude, log = FALSE,
-        ref_lat = 38.8986312, ref_lon = -77.0062457,
+        lat = latitude,
+        lon = longitude,
+        log = FALSE,
+        ref_lat = 38.8986312,
+        ref_lon = -77.0062457,
         is_lat_lon = TRUE
       ) %>%
       prep()
   )
   postal <- tibble(latitude = -100, longitude = 0)
-  expect_snapshot(error = TRUE,
+  expect_snapshot(
+    error = TRUE,
     near_station <- recipe(~., data = postal) %>%
       step_geodist(
-        lat = latitude, lon = longitude, log = FALSE,
-        ref_lat = 38.8986312, ref_lon = -77.0062457,
+        lat = latitude,
+        lon = longitude,
+        log = FALSE,
+        ref_lat = 38.8986312,
+        ref_lon = -77.0062457,
         is_lat_lon = TRUE
       ) %>%
       prep()
   )
 
   postal <- tibble(latitude = 0, longitude = -190)
-  expect_snapshot(error = TRUE,
+  expect_snapshot(
+    error = TRUE,
     near_station <- recipe(~., data = postal) %>%
       step_geodist(
-        lat = latitude, lon = longitude, log = FALSE,
-        ref_lat = 38.8986312, ref_lon = -77.0062457,
+        lat = latitude,
+        lon = longitude,
+        log = FALSE,
+        ref_lat = 38.8986312,
+        ref_lon = -77.0062457,
         is_lat_lon = TRUE
       ) %>%
       prep()
@@ -172,49 +217,65 @@ test_that("bad args", {
   rand_data_2$y1 <- runif(nrow(rand_data_2))
   rec <- recipe(~., data = rand_data_2)
 
-  expect_snapshot(error = TRUE,
+  expect_snapshot(
+    error = TRUE,
     rec %>%
       step_geodist(starts_with("x"), y, ref_lat = 0.5, ref_lon = 0.25) %>%
       prep(training = rand_data_2)
   )
-  expect_snapshot(error = TRUE,
+  expect_snapshot(
+    error = TRUE,
     rec %>%
       step_geodist(x, starts_with("y"), ref_lat = 0.5, ref_lon = 0.25) %>%
       prep(training = rand_data_2)
   )
-  expect_snapshot(error = TRUE,
+  expect_snapshot(
+    error = TRUE,
     rec %>%
       step_geodist(x, y, ref_lat = letters[1:2], ref_lon = 0.25) %>%
       prep(training = rand_data_2)
   )
-  expect_snapshot(error = TRUE,
+  expect_snapshot(
+    error = TRUE,
     rec %>%
       step_geodist(x, y, ref_lon = letters[1:2], ref_lat = 0.25) %>%
       prep(training = rand_data_2)
   )
-  expect_snapshot(error = TRUE,
+  expect_snapshot(
+    error = TRUE,
     rec %>%
       step_geodist(x, y, ref_lon = 0.5, ref_lat = 0.25, name = 1) %>%
       prep(training = rand_data_2)
   )
-  expect_snapshot(error = TRUE,
+  expect_snapshot(
+    error = TRUE,
     rec %>%
       step_geodist(x, y, ref_lon = 0.5, ref_lat = 0.25, log = exp(1)) %>%
       prep(training = rand_data_2)
   )
-  expect_snapshot(error = TRUE,
-   recipe(~ x + y, data = rand_data) %>%
-     step_geodist(x, y,
-                  ref_lat = 0.5, ref_lon = 0.25, is_lat_lon = "no",
-                  log = FALSE
-     ) %>%
-     prep(training = rand_data)
+  expect_snapshot(
+    error = TRUE,
+    recipe(~x + y, data = rand_data) %>%
+      step_geodist(
+        x,
+        y,
+        ref_lat = 0.5,
+        ref_lon = 0.25,
+        is_lat_lon = "no",
+        log = FALSE
+      ) %>%
+      prep(training = rand_data)
   )
-  expect_snapshot(error = TRUE,
-    recipe(~ x + y, data = rand_data) %>%
-      step_geodist(x, y,
-                   ref_lat = 0.5, ref_lon = 0.25, is_lat_lon = c(TRUE, TRUE),
-                   log = FALSE
+  expect_snapshot(
+    error = TRUE,
+    recipe(~x + y, data = rand_data) %>%
+      step_geodist(
+        x,
+        y,
+        ref_lat = 0.5,
+        ref_lon = 0.25,
+        is_lat_lon = c(TRUE, TRUE),
+        log = FALSE
       ) %>%
       prep(training = rand_data)
   )
@@ -223,17 +284,21 @@ test_that("bad args", {
 # Infrastructure ---------------------------------------------------------------
 
 test_that("bake method errors when needed non-standard role columns are missing", {
-  rec <- recipe(~ x + y, data = rand_data) %>%
-    step_geodist(x, y,
-                 ref_lat = 0.5, ref_lon = 0.25, is_lat_lon = FALSE,
-                 log = FALSE
+  rec <- recipe(~x + y, data = rand_data) %>%
+    step_geodist(
+      x,
+      y,
+      ref_lat = 0.5,
+      ref_lon = 0.25,
+      is_lat_lon = FALSE,
+      log = FALSE
     ) %>%
     update_role(x, y, new_role = "potato") %>%
     update_role_requirements(role = "potato", bake = FALSE)
   rec_trained <- prep(rec, rand_data)
-  
+
   expect_snapshot(
-    error = TRUE, 
+    error = TRUE,
     bake(rec_trained, new_data = rand_data[, 2, drop = FALSE])
   )
 })
@@ -286,10 +351,13 @@ test_that("empty selection tidy method works", {
 test_that("keep_original_cols works", {
   new_names <- c("geo_dist")
 
-  rec <- recipe(~ x + y, data = rand_data) %>%
+  rec <- recipe(~x + y, data = rand_data) %>%
     step_geodist(
-      x, y,
-      ref_lat = 0.5, ref_lon = 0.25, is_lat_lon = FALSE,
+      x,
+      y,
+      ref_lat = 0.5,
+      ref_lon = 0.25,
+      is_lat_lon = FALSE,
       keep_original_cols = FALSE
     )
 
@@ -301,10 +369,13 @@ test_that("keep_original_cols works", {
     new_names
   )
 
-  rec <- recipe(~ x + y, data = rand_data) %>%
+  rec <- recipe(~x + y, data = rand_data) %>%
     step_geodist(
-      x, y,
-      ref_lat = 0.5, ref_lon = 0.25, is_lat_lon = FALSE,
+      x,
+      y,
+      ref_lat = 0.5,
+      ref_lon = 0.25,
+      is_lat_lon = FALSE,
       keep_original_cols = TRUE
     )
 
@@ -318,10 +389,13 @@ test_that("keep_original_cols works", {
 })
 
 test_that("keep_original_cols - can prep recipes with it missing", {
-  rec <- recipe(~ x + y, data = rand_data) %>%
+  rec <- recipe(~x + y, data = rand_data) %>%
     step_geodist(
-      x, y,
-      ref_lat = 0.5, ref_lon = 0.25, is_lat_lon = FALSE
+      x,
+      y,
+      ref_lat = 0.5,
+      ref_lon = 0.25,
+      is_lat_lon = FALSE
     )
 
   rec$steps[[1]]$keep_original_cols <- NULL
@@ -336,10 +410,13 @@ test_that("keep_original_cols - can prep recipes with it missing", {
 })
 
 test_that("printing", {
-  rec <- recipe(~ x + y, data = rand_data) %>%
+  rec <- recipe(~x + y, data = rand_data) %>%
     step_geodist(
-      x, y,
-      ref_lat = 0.5, ref_lon = 0.25, is_lat_lon = FALSE
+      x,
+      y,
+      ref_lat = 0.5,
+      ref_lon = 0.25,
+      is_lat_lon = FALSE
     )
 
   expect_snapshot(print(rec))
