@@ -54,9 +54,11 @@ test_that("Date class", {
 
 test_that("Date class", {
   holiday_rec <- recipe(~day, test_data) %>%
-    step_holiday(all_predictors(),
-                 holidays = exp_dates$holiday,
-                 keep_original_cols = FALSE)
+    step_holiday(
+      all_predictors(),
+      holidays = exp_dates$holiday,
+      keep_original_cols = FALSE
+    )
 
   holiday_rec <- prep(holiday_rec, training = test_data)
   holiday_ind <- bake(holiday_rec, test_data, all_predictors())
@@ -132,9 +134,11 @@ test_that("Date class", {
   exp_dates$date <- as.POSIXct(exp_dates$date)
 
   holiday_rec <- recipe(~day, test_data) %>%
-    step_holiday(all_predictors(),
-                 holidays = exp_dates$holiday,
-                 keep_original_cols = FALSE)
+    step_holiday(
+      all_predictors(),
+      holidays = exp_dates$holiday,
+      keep_original_cols = FALSE
+    )
 
   holiday_rec <- prep(holiday_rec, training = test_data)
   holiday_ind <- bake(holiday_rec, test_data, all_predictors())
@@ -142,7 +146,6 @@ test_that("Date class", {
   expect_true(all(vapply(holiday_ind, is.integer, logical(1))))
 })
 
-
 test_that("works with no missing values - POSIXct class", {
   test_data <- na.omit(test_data)
 
@@ -190,6 +193,51 @@ test_that("error on incorrect holidays argument", {
   )
 })
 
+test_that("sparse = 'yes' works", {
+  rec <- recipe(~., data = test_data)
+
+  dense <- rec %>%
+    step_holiday(day, sparse = "no", keep_original_cols = FALSE) %>%
+    prep() %>%
+    bake(NULL)
+  dense <- purrr::map(dense, as.integer) %>% tibble::new_tibble()
+  sparse <- rec %>%
+    step_holiday(day, sparse = "yes", keep_original_cols = FALSE) %>%
+    prep() %>%
+    bake(NULL)
+
+  expect_identical(dense, sparse)
+
+  expect_false(any(vapply(dense, sparsevctrs::is_sparse_vector, logical(1))))
+  expect_true(all(vapply(sparse, sparsevctrs::is_sparse_vector, logical(1))))
+})
+
+test_that("sparse argument is backwards compatible", {
+  rec <- recipe(~., data = test_data) %>%
+    step_holiday(day) %>%
+    prep()
+
+  exp <- bake(rec, test_data)
+
+  # Simulate old recipe
+  rec$steps[[1]]$sparse <- NULL
+
+  expect_identical(
+    bake(rec, test_data),
+    exp
+  )
+})
+
+test_that(".recipes_toggle_sparse_args works", {
+  rec <- recipe(~., data = test_data) %>%
+    step_holiday(day, sparse = "auto", keep_original_cols = TRUE)
+
+  expect_equal(
+    .recipes_estimate_sparsity(rec),
+    364 / 365
+  )
+})
+
 # Infrastructure ---------------------------------------------------------------
 
 test_that("bake method errors when needed non-standard role columns are missing", {
@@ -244,8 +292,11 @@ test_that("keep_original_cols works", {
   new_names <- c("day_ChristmasDay", "day_USMemorialDay", "day_Easter")
 
   rec <- recipe(~day, test_data) %>%
-    step_holiday(all_predictors(), holidays = exp_dates$holiday,
-                 keep_original_cols = FALSE)
+    step_holiday(
+      all_predictors(),
+      holidays = exp_dates$holiday,
+      keep_original_cols = FALSE
+    )
 
   rec <- prep(rec)
   res <- bake(rec, new_data = NULL)
@@ -256,8 +307,11 @@ test_that("keep_original_cols works", {
   )
 
   rec <- recipe(~day, test_data) %>%
-    step_holiday(all_predictors(), holidays = exp_dates$holiday,
-                 keep_original_cols = TRUE)
+    step_holiday(
+      all_predictors(),
+      holidays = exp_dates$holiday,
+      keep_original_cols = TRUE
+    )
 
   rec <- prep(rec)
   res <- bake(rec, new_data = NULL)
@@ -269,7 +323,7 @@ test_that("keep_original_cols works", {
 })
 
 test_that("keep_original_cols - can prep recipes with it missing", {
-  rec <-  recipe(~day, test_data) %>%
+  rec <- recipe(~day, test_data) %>%
     step_holiday(all_predictors(), holidays = exp_dates$holiday)
 
   rec$steps[[1]]$keep_original_cols <- NULL
