@@ -3,23 +3,33 @@ library(recipes)
 
 ## expected results form the `dimRed` package
 
-exp_res <- structure(list(
-  Isomap1 = c(
-    0.312570873898531, 0.371885353599467, 2.23124009833741,
-    0.248271457498181, -0.420128801874122
+exp_res <- structure(
+  list(
+    Isomap1 = c(
+      0.312570873898531,
+      0.371885353599467,
+      2.23124009833741,
+      0.248271457498181,
+      -0.420128801874122
+    ),
+    Isomap2 = c(
+      -0.443724171391742,
+      -0.407721529759647,
+      0.245721022395862,
+      3.112001672258,
+      0.0292770508011519
+    ),
+    Isomap3 = c(
+      0.761529345514676,
+      0.595015565588918,
+      1.59943072269788,
+      0.566884409484389,
+      1.53770327701819
+    )
   ),
-  Isomap2 = c(
-    -0.443724171391742, -0.407721529759647, 0.245721022395862,
-    3.112001672258, 0.0292770508011519
-  ),
-  Isomap3 = c(
-    0.761529345514676, 0.595015565588918, 1.59943072269788,
-    0.566884409484389, 1.53770327701819
-  )
-),
-.Names = c("Isomap1", "Isomap2", "Isomap3"),
-class = c("tbl_df", "tbl", "data.frame"),
-row.names = c(NA, -5L)
+  .Names = c("Isomap1", "Isomap2", "Isomap3"),
+  class = c("tbl_df", "tbl", "data.frame"),
+  row.names = c(NA, -5L)
 )
 
 set.seed(1)
@@ -86,7 +96,6 @@ test_that("No ISOmap", {
   )
 })
 
-
 test_that("ISOmap fails gracefully", {
   skip_on_cran()
   skip_if_not_installed("RSpectra")
@@ -95,7 +104,8 @@ test_that("ISOmap fails gracefully", {
   skip_if_not_installed("dimRed")
   skip_if(getRversion() <= "3.4.4")
 
-  expect_snapshot(error = TRUE,
+  expect_snapshot(
+    error = TRUE,
     recipe(Sepal.Length ~ ., data = iris) %>%
       step_bs(Sepal.Width, deg_free = 1, degree = 1) %>%
       step_bs(Sepal.Length, deg_free = 1, degree = 1) %>%
@@ -116,7 +126,7 @@ test_that("check_name() is used", {
   dat <- dplyr::as_tibble(dat1)
   dat$Isomap1 <- dat$x1
 
-  rec <- recipe(~ ., data = dat) %>%
+  rec <- recipe(~., data = dat) %>%
     step_isomap(x1, x2, x3, neighbors = 3, num_terms = 3)
 
   expect_snapshot(
@@ -129,7 +139,7 @@ test_that("check_name() is used", {
 test_that("tunable", {
   rec <-
     recipe(~., data = iris) %>%
-    step_isomap(all_predictors())
+      step_isomap(all_predictors())
   rec_param <- tunable.step_isomap(rec$steps[[1]])
   expect_equal(rec_param$name, c("num_terms", "neighbors"))
   expect_true(all(rec_param$source == "recipe"))
@@ -209,8 +219,14 @@ test_that("keep_original_cols works", {
   new_names <- c("Isomap1", "Isomap2", "Isomap3")
 
   rec <- recipe(~., data = dat1) %>%
-    step_isomap(x1, x2, x3, neighbors = 3, num_terms = 3,
-                keep_original_cols = FALSE)
+    step_isomap(
+      x1,
+      x2,
+      x3,
+      neighbors = 3,
+      num_terms = 3,
+      keep_original_cols = FALSE
+    )
 
   rec <- prep(rec)
   res <- bake(rec, new_data = NULL)
@@ -221,8 +237,14 @@ test_that("keep_original_cols works", {
   )
 
   rec <- recipe(~., data = dat1) %>%
-    step_isomap(x1, x2, x3, neighbors = 3, num_terms = 3,
-                keep_original_cols = TRUE)
+    step_isomap(
+      x1,
+      x2,
+      x3,
+      neighbors = 3,
+      num_terms = 3,
+      keep_original_cols = TRUE
+    )
 
   rec <- prep(rec)
   res <- bake(rec, new_data = NULL)
@@ -276,7 +298,8 @@ test_that("tunable is setup to work with extract_parameter_set_dials", {
   rec <- recipe(~., data = mtcars) %>%
     step_isomap(
       all_predictors(),
-      num_terms = hardhat::tune(), neighbors = hardhat::tune()
+      num_terms = hardhat::tune(),
+      neighbors = hardhat::tune()
     )
 
   params <- extract_parameter_set_dials(rec)
@@ -294,7 +317,7 @@ test_that("bad args", {
 
   expect_snapshot(
     recipe(~., data = mtcars) %>%
-      step_isomap(all_predictors(), num_terms = 2, neighbors = -1/3) %>%
+      step_isomap(all_predictors(), num_terms = 2, neighbors = -1 / 3) %>%
       prep(),
     error = TRUE
   )
